package com.tillekesoft.dragtome;

import anywheresoftware.b4a.BA;
import javafx.event.EventHandler;
import javafx.scene.input.DragEvent;
import javafx.scene.input.Dragboard;
import javafx.scene.input.TransferMode;

import java.io.File;
import java.util.Collection;



@BA.Version(0.80F)
@BA.Author("Moster67 aka Mikael Osterhed")

@BA.Events(values = {"ReceivedFilePath (Filepath as String)"})
@BA.ShortName("B4JDragToMe")
public class B4JDragToMe {

    private BA ba;
    private String eventName;
    private String ReceivedFilePath = null;
    private javafx.scene.control.Control control;

    private void ForwardReceivedFilePath (String path){
        if (ba.subExists(eventName + "_receivedfilepath")){
            ba.raiseEvent(B4JDragToMe.this, eventName + "_receivedfilepath", new Object[] { path });
        }
    }

    /**
     * Initialize by setting your ControlView and giving an event-name.
     * For files, the event ReceivedFilePath returns the filepath/location of the dragged object
     * while it will return the URL for an http-link.
     */
    public void Initialize(final BA ba, javafx.scene.control.Control Control, String EventName) {
        this.ba = ba;
        this.eventName = EventName.toLowerCase(BA.cul);
        this.control = Control;
        addControlEvents();
    }

    private void addControlEvents(){
        control.setOnDragOver(new EventHandler<DragEvent>() {

            @Override
            public void handle(DragEvent event) {
                if (event.getGestureSource() != control && event.getDragboard().hasFiles()) {
                    event.acceptTransferModes(TransferMode.LINK);
                }
                if (event.getGestureSource() != control && event.getDragboard().hasUrl()) {
                    event.acceptTransferModes(TransferMode.LINK);
                }

                event.consume();
            }
        });

        control.setOnDragDropped(new EventHandler<DragEvent>() {

            @Override
            public void handle(DragEvent event) {
                Dragboard dragboard = event.getDragboard();
                boolean success = false;
                File newFile = null;

                if (dragboard.hasUrl() && !dragboard.hasFiles()) {
                    ReceivedFilePath = dragboard.getUrl();
                    success = true;
                    ForwardReceivedFilePath(ReceivedFilePath);
                } else if (dragboard.hasFiles()){
                    Collection<File> newFiles = dragboard.getFiles();
                    if (!newFiles.isEmpty())
                        newFile = (File) newFiles.toArray()[0];
                    ReceivedFilePath = newFile.getAbsolutePath();
                    success = true;
                    ForwardReceivedFilePath(ReceivedFilePath);
                }

                event.setDropCompleted(success);
                event.consume();

            }
        });
    }


} //end of class


