package com.tillekesoft.dragtome;

import anywheresoftware.b4a.BA;
import javafx.event.EventHandler;
import javafx.scene.image.Image;
import javafx.scene.input.DragEvent;
import javafx.scene.input.Dragboard;
import javafx.scene.input.TransferMode;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Collection;
import java.util.List;


@BA.Events(values = {"Result (Success as Boolean)"})
@BA.ShortName("B4JDragToMeCompleteImageView")
public class B4JDragToMeCompleteImageView {
    private BA ba;
    private String eventName;
    private String ReceivedFilePath = null;
    private javafx.scene.image.ImageView imageView;


    private void forwardStatus (boolean result){
        if (ba.subExists(eventName + "_result")){
                ba.raiseEvent(B4JDragToMeCompleteImageView.this, eventName + "_result", new Object[] { result });
        }
    }

    /**
     * This object will load an image onto an imageview.
     * Initialize by setting your ImageView and giving an event-name.
     * The result-event will indicate if the operation was successful or not.
     */
    public void Initialize(final BA ba,javafx.scene.image.ImageView ImageView,  String EventName) {
        this.ba = ba;
        this.eventName = EventName.toLowerCase(BA.cul);
        this.imageView = ImageView;
        addImageEvents();
    }

    private void addImageEvents(){
        imageView.setOnDragOver(new EventHandler<DragEvent>() {

            @Override
            public void handle(DragEvent event) {
                Dragboard dragBoard = event.getDragboard();
                if (dragBoard.hasFiles()) {
                    List<File> files = dragBoard.getFiles();
                    String path = files
                            .get(0)
                            .toPath()
                            .toString();
                    if (path.endsWith(".jpeg") ||
                            path.endsWith(".jpg") ||
                            path.endsWith(".png") ||
                            path.endsWith(".gif")) {
                        event.acceptTransferModes(TransferMode.ANY);
                    } else{
                        forwardStatus(false);
                    }

                }
                event.consume();
            }
        });

        imageView.setOnDragDropped(new EventHandler<DragEvent>() {

            @Override
            public void handle(DragEvent event) {
                List<File> files = event.getDragboard().getFiles();
                boolean success = false;
                try {
                    imageView.setImage(new Image(new FileInputStream(files.get(0))));
                } catch (FileNotFoundException e) {
                    e.printStackTrace();
                }
                success = true;
                forwardStatus(true);

                event.setDropCompleted(success);
                event.consume();

            }
        });
    }

}
